aboutsummaryrefslogtreecommitdiffstats
path: root/config/hypr/scripts/RefreshNoWaybar.sh
diff options
context:
space:
mode:
authorJa.KooLit <ejhay.games@gmail.com>2023-12-29 00:41:08 +0900
committerJa.KooLit <ejhay.games@gmail.com>2023-12-29 00:41:08 +0900
commitf0771edf369d3ea51e3322acb9a5baa456f732b1 (patch)
tree96a01b7586d716c03f73380ac22e46a241eb8266 /config/hypr/scripts/RefreshNoWaybar.sh
parent9bf8a87dfa62865111c94e97a9abafcb529e52ed (diff)
Re-Structured Hypr Folder in preparation for Updates Scripts
Diffstat (limited to 'config/hypr/scripts/RefreshNoWaybar.sh')
-rwxr-xr-xconfig/hypr/scripts/RefreshNoWaybar.sh21
1 files changed, 17 insertions, 4 deletions
diff --git a/config/hypr/scripts/RefreshNoWaybar.sh b/config/hypr/scripts/RefreshNoWaybar.sh
index dc99b623..be06167c 100755
--- a/config/hypr/scripts/RefreshNoWaybar.sh
+++ b/config/hypr/scripts/RefreshNoWaybar.sh
@@ -5,6 +5,16 @@
# Modified inorder to refresh rofi background, Pywal
SCRIPTSDIR=$HOME/.config/hypr/scripts
+UserSCRIPTSDIR=$HOME/.config/hypr/UserScripts
+
+# Define file_exists function
+file_exists() {
+ if [ -e "$1" ]; then
+ return 0 # File exists
+ else
+ return 1 # File does not exist
+ fi
+}
# Kill already running processes
_ps=(rofi)
@@ -17,10 +27,13 @@ done
# Pywal refresh
${SCRIPTSDIR}/PywalSwww.sh &
-
-# Relaunching rainbow borders
+# Relaunching rainbow borders if the script exists
sleep 1
-${SCRIPTSDIR}/RainbowBorders.sh &
+if file_exists "${UserSCRIPTSDIR}/RainbowBorders.sh"; then
+ ${UserSCRIPTSDIR}/RainbowBorders.sh &
+fi
# for cava-pywal (note, need to manually restart cava once wallpaper changes)
-ln -sf "$HOME/.cache/wal/cava-colors" "$HOME/.config/cava/config" || true \ No newline at end of file
+ln -sf "$HOME/.cache/wal/cava-colors" "$HOME/.config/cava/config" || true
+
+exit 0 \ No newline at end of file
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage